"use client";
import clsx from "clsx";
import { useState } from "react";
import { useFormState } from "react-dom";
import { Input } from "~/components/ui/input";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "~/components/ui/select";
import { addRegion } from "~/server/actions/addRegion";

type Region = {
  id: string;
  name: string;
  countryId: string;
};
type Country = {
  id: string;
  name: string;
};

export default function CreateSubRegionForm(props: {
  regions: Region[];
  countries: Country[];
}) {
  const { countries, regions } = props;
  const [country, setCountry] = useState<Country | undefined>(undefined);
  const [formState, formActions] = useFormState(addRegion, {
    message: "",
    errors: undefined,
    fieldValues: {
      name: "",
      regionId: "",
    },
  });
  return (
    <div>
      {/* country selector */}
      <Select name="country">
        <SelectTrigger
          className={`w-[180px] ${clsx({ "border-red-500": formState.errors?.countryId })}`}
        >
          <SelectValue placeholder="Country" />
        </SelectTrigger>
        <SelectContent>
          {countries.map((country) => (
            <SelectItem key={country.id} value={country.id}>
              {country.name}
            </SelectItem>
          ))}
        </SelectContent>
      </Select>
      <form action={formActions}>
        {/* region selector */}
        <Select name="subRegion">
          <SelectTrigger
            className={`w-[180px] ${clsx({ "border-red-500": formState.errors?.countryId })}`}
          >
            <SelectValue placeholder="Region" />
          </SelectTrigger>
          <SelectContent>
            {regions.map((region) => (
              <SelectItem key={region.id} value={region.id}>
                {region.name}
              </SelectItem>
            ))}
          </SelectContent>
        </Select>
        <Input
          name="name"
          id="name"
          placeholder="Name"
          className={`${clsx({ "border-red-500": formState.errors?.name })}`}
        />
      </form>
    </div>
  );
}
