"use server";

import { revalidatePath } from "next/cache";
import { db } from "../db";
import { countries } from "../db/schema";
import { ZodError, z } from "zod";
import { eq } from "drizzle-orm";

export async function addCountry(prevstate: any, formData: FormData) {
  //assign formdaata to variables.
  const name = (formData.get("name") as string).toLowerCase();
  //check if country already exists
  const exists = await db
    .select({ name: countries.name })
    .from(countries)
    .where(eq(countries.name, name));

  //Define the schema for the form data
  const schema = z.object({
    name: z
      .string()
      .min(1, { message: "Name is required" })
      .refine(() => !exists, { message: `${name} already exists` }),
  });
  //Parse the form data using the schema for validation, and check if the name already exists
  try {
    schema.parse({
      name,
    });
    //If the name doesn't exist, add the country to the database abd revalidate the page
    await db.insert(countries).values({ name });
    revalidatePath("/");
    //Return a success message
    return {
      message: "success",
      errors: undefined,
      fieldValues: {
        name: "",
      },
    };
  } catch (error) {
    const zodError = error as ZodError;
    const errorMap = zodError.flatten().fieldErrors;
    //Return an error object with the field values and errors.
    return {
      message: "error",
      errors: {
        name: errorMap["name"]?.[0] ?? "",
      },
      fieldValues: {
        name,
      },
    };
  }
}
