"use server";

import { eq } from "drizzle-orm";
import { db } from "../db";
import { subRegions } from "../db/schema";
import { ZodError, z } from "zod";

export const addSubRegion = async (prevstate: any, formData: FormData) => {
  //assign formdaata to variables.
  const name = (formData.get("name") as string).toLowerCase();
  const regionId = formData.get("region") as string;

  //check if region already exists in country
  const exists = await db
    .select({ name: subRegions.name })
    .from(subRegions)
    .where(eq(subRegions.regionId, regionId) && eq(subRegions.name, name));

  //Define the schema for the form data
  const schema = z.object({
    regionId: z.string().min(1, "No region selected"),
    name: z
      .string()
      .min(1, "Name is required")
      .refine(() => !exists, {
        message: `${name} already exists in selected region`,
      }),
  });
  //Parse the form data using the schema for validation, and check if the name already exists
  try {
    schema.parse({
      regionId,
      name,
    });
    //If the name doesn't exist, add the country to the database abd revalidate the page
    await db.insert(subRegions).values({ regionId, name });
    //Return a success message
    return {
      message: "success",
      errors: undefined,
      fieldValues: {
        name: "",
        regionId: "",
      },
    };
  } catch (error) {
    const zodError = error as ZodError;
    const errorMap = zodError.flatten().fieldErrors;
    //Return an error object with the field values and errors.
    return {
      message: "error",
      errors: {
        name: errorMap["name"]?.[0] ?? "",
        regionId: errorMap["regionId"]?.[0] ?? "",
      },
      fieldValues: {
        name,
        regionId,
      },
    };
  }
};
